@@ -3,9 +3,8 @@ package JQ::Lite;
 use strict;
 use warnings;
 use JSON::PP;
-use Data::Dumper;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub new {
     my ($class, %opts) = @_;
@@ -138,7 +137,23 @@ sub _traverse {
 sub _evaluate_condition {
     my ($item, $cond) = @_;
 
-    # 例: .profile.country == "JP"
+    # 複数条件対応：分割して再帰評価
+    if ($cond =~ /\s+and\s+/i) {
+        my @conds = split /\s+and\s+/i, $cond;
+        for my $c (@conds) {
+            return 0 unless _evaluate_condition($item, $c);
+        }
+        return 1;
+    }
+    if ($cond =~ /\s+or\s+/i) {
+        my @conds = split /\s+or\s+/i, $cond;
+        for my $c (@conds) {
+            return 1 if _evaluate_condition($item, $c);
+        }
+        return 0;
+    }
+
+    # 単一条件パターン
     if ($cond =~ /^\s*\.(.+?)\s*(==|!=|>=|<=|>|<)\s*(.+?)\s*$/) {
         my ($path, $op, $value_raw) = ($1, $2, $3);
 
@@ -155,9 +170,8 @@ sub _evaluate_condition {
             $value = $value_raw;
         }
 
-        # 新しく: _traverse を使って値を取得
         my @values = _traverse($item, $path);
-        my $field_val = $values[0];  # 最初の値だけ比較（配列対応は後回し）
+        my $field_val = $values[0];
 
         return eval {
             return 0 unless defined $field_val;
@@ -192,6 +206,10 @@ __END__
 
 JQ::Lite - A lightweight jq-like JSON query engine in Perl
 
+=head1 VERSION
+
+Version 0.05
+
 =head1 SYNOPSIS
 
   use JQ::Lite;
@@ -208,6 +226,50 @@ JQ::Lite - A lightweight jq-like JSON query engine in Perl
 JQ::Lite is a minimal Perl module that allows querying JSON data
 using a simplified jq-like syntax.
 
+Currently supported features:
+
+=over 4
+
+=item * Dot-based key access (e.g. .users[].name)
+
+=item * Optional key access with ? (e.g. .nickname?)
+
+=item * Array indexing and flattening (e.g. .users[0], .users[])
+
+=item * Built-in functions: length, keys
+
+=item * select(...) filters with comparison and logical operators
+
+=back
+
+=head1 METHODS
+
+=head2 new
+
+  my $jq = JQ::Lite->new;
+
+Creates a new JQ::Lite instance.
+
+=head2 run_query
+
+  my @results = $jq->run_query($json_text, $query);
+
+Runs a query string against the given JSON text.
+
+=head1 REQUIREMENTS
+
+This module uses only core Perl modules:
+
+=over 4
+
+=item * JSON::PP
+
+=back
+
+=head1 SEE ALSO
+
+L<jq>, L<JSON::XS>, L<JSON::PP>
+
 =head1 AUTHOR
 
 Kawamura Shingo <pannakoota1@gmail.com>
@@ -217,3 +279,7 @@ Kawamura Shingo <pannakoota1@gmail.com>
 Same as Perl itself.
 
 =cut
+
+Same as Perl itself.
+
+=cut
